==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/BulkProcessInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[BulkProcessInteraction]
AS
BEGIN
	/*
	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE [dbo].[Audio] SET
		[dbo].[Audio].[Format] = [dbo].[#ProcessInteractionTemp].[Format],
		[dbo].[Audio].[MediaInfoTime] = [dbo].[#ProcessInteractionTemp].[MediaInfoTime],
		[dbo].[Audio].[DurationLinguisticTime] = [dbo].[#ProcessInteractionTemp].[DurationLinguisticTime],
		[dbo].[Audio].[IsDiariced] = [dbo].[#ProcessInteractionTemp].[IsDiariced],
		[dbo].[Audio].[ChannelsChanged] = [dbo].[#ProcessInteractionTemp].[ChannelsChanged],
		[dbo].[Audio].[ValidChar] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidChar], [dbo].[Audio].[ValidChar]),
		[dbo].[Audio].[ValidWords] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidWords], [dbo].[Audio].[ValidWords]),
		[dbo].[Audio].[TotalPhrases] = [dbo].[#ProcessInteractionTemp].[TotalPhrases],
		[dbo].[Audio].[CharsPerPhrase] = [dbo].[#ProcessInteractionTemp].[CharsPerPhrase],
		[dbo].[Audio].[IsTranscribed] = [dbo].[#ProcessInteractionTemp].[IsTranscribed],
		[dbo].[Audio].[IsCancel] = [dbo].[#ProcessInteractionTemp].[IsCancel],
		[dbo].[Audio].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
		[dbo].[Audio].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
		[dbo].[Audio].[LastModifiedDate] = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE
		[dbo].[Audio].[VCC] = [dbo].[#ProcessInteractionTemp].[VCC]
		AND [dbo].[Audio].[ID] = [dbo].[#ProcessInteractionTemp].[ID]
		AND [dbo].[Audio].[Section] = [dbo].[#ProcessInteractionTemp].[Section]
		AND [dbo].[Audio].[Part] = [dbo].[#ProcessInteractionTemp].[Part]
		AND [dbo].[#ProcessInteractionTemp].[Channel] = 'CALL'
	*/

	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE A
		SET A.[Format] = PIT.[Format],
			A.[MediaInfoTime] = PIT.[MediaInfoTime],
			A.[DurationLinguisticTime] = PIT.[DurationLinguisticTime],
			A.[IsDiariced] = PIT.[IsDiariced],
			A.[ChannelsChanged] = PIT.[ChannelsChanged],
			A.[ValidChar] = ISNULL(PIT.[ValidChar], A.[ValidChar]),
			A.[ValidWords] = ISNULL(PIT.[ValidWords], A.[ValidWords]),
			A.[TotalPhrases] = PIT.[TotalPhrases],
			A.[CharsPerPhrase] = PIT.[CharsPerPhrase],
			A.[IsTranscribed] = PIT.[IsTranscribed],
			A.[IsCancel] = PIT.[IsCancel],
			A.[FileName] = PIT.[FileName],
			A.[ErrorMessage] = PIT.[ErrorMessage],
			A.[LastModifiedDate] = GETUTCDATE()
		FROM [dbo].[Audio] A
		INNER JOIN [dbo].[#ProcessInteractionTemp] PIT
			ON PIT.[VCC] = PIT.[VCC]
				AND A.[ID] = PIT.[ID]
				AND A.[Section] = PIT.[Section]
				AND A.[Part] = PIT.[Part]
		WHERE PIT.[Channel] = 'CALL'

	-- ACTUALIZAMOS LOS TEXT CON EL RESULTADO DE LA TABLA
	UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[ValidChar] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidChar], [dbo].[AsyncInteraction].[ValidChar]),
			[dbo].[AsyncInteraction].[ValidWords] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidWords], [dbo].[AsyncInteraction].[ValidWords]),
			[dbo].[AsyncInteraction].[TotalPhrases] = [dbo].[#ProcessInteractionTemp].[TotalPhrases],
			[dbo].[AsyncInteraction].[CharsPerPhrase] = [dbo].[#ProcessInteractionTemp].[CharsPerPhrase],
			[dbo].[AsyncInteraction].[IsTranscribed] = [dbo].[#ProcessInteractionTemp].[IsTranscribed],
			[dbo].[AsyncInteraction].[IsCancel] = [dbo].[#ProcessInteractionTemp].[IsCancel],
			[dbo].[AsyncInteraction].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
			[dbo].[AsyncInteraction].[ViewFileName] = [dbo].[#ProcessInteractionTemp].[ViewFileName],
			[dbo].[AsyncInteraction].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
			[dbo].[AsyncInteraction].[LastModifiedDate] = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE [dbo].[AsyncInteraction].[VCC] = [dbo].[#ProcessInteractionTemp].[VCC]
		AND [dbo].[AsyncInteraction].[Campaign] = [dbo].[#ProcessInteractionTemp].[Campaign]
		AND [dbo].[AsyncInteraction].[Channel] = [dbo].[#ProcessInteractionTemp].[Channel]
		AND [dbo].[AsyncInteraction].[ID] = [dbo].[#ProcessInteractionTemp].[ID]
		AND [dbo].[AsyncInteraction].[Folder] = [dbo].[#ProcessInteractionTemp].[Folder]

	DROP TABLE [dbo].[#ProcessInteractionTemp]
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_7.1.0_database.tar.gz: database/mssql/procedures/BulkProcessInteraction.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[BulkProcessInteraction]
AS
BEGIN
	/*
	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE [dbo].[Audio] SET
		[dbo].[Audio].[Format] = [dbo].[#ProcessInteractionTemp].[Format],
		[dbo].[Audio].[MediaInfoTime] = [dbo].[#ProcessInteractionTemp].[MediaInfoTime],
		[dbo].[Audio].[DurationLinguisticTime] = [dbo].[#ProcessInteractionTemp].[DurationLinguisticTime],
		[dbo].[Audio].[IsDiariced] = [dbo].[#ProcessInteractionTemp].[IsDiariced],
		[dbo].[Audio].[ChannelsChanged] = [dbo].[#ProcessInteractionTemp].[ChannelsChanged],
		[dbo].[Audio].[ValidChar] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidChar], [dbo].[Audio].[ValidChar]),
		[dbo].[Audio].[ValidWords] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidWords], [dbo].[Audio].[ValidWords]),
		[dbo].[Audio].[TotalPhrases] = [dbo].[#ProcessInteractionTemp].[TotalPhrases],
		[dbo].[Audio].[CharsPerPhrase] = [dbo].[#ProcessInteractionTemp].[CharsPerPhrase],
		[dbo].[Audio].[IsTranscribed] = [dbo].[#ProcessInteractionTemp].[IsTranscribed],
		[dbo].[Audio].[IsCancel] = [dbo].[#ProcessInteractionTemp].[IsCancel],
		[dbo].[Audio].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
		[dbo].[Audio].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
		[dbo].[Audio].[LastModifiedDate] = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE
		[dbo].[Audio].[VCC] = [dbo].[#ProcessInteractionTemp].[VCC]
		AND [dbo].[Audio].[ID] = [dbo].[#ProcessInteractionTemp].[ID]
		AND [dbo].[Audio].[Section] = [dbo].[#ProcessInteractionTemp].[Section]
		AND [dbo].[Audio].[Part] = [dbo].[#ProcessInteractionTemp].[Part]
		AND [dbo].[#ProcessInteractionTemp].[Channel] = 'CALL'
	*/

	-- ACTUALIZAMOS LOS AUDIOS CON EL RESULTADO EN LA TABLA
	UPDATE A
		SET A.[Format] = PIT.[Format],
			A.[MediaInfoTime] = PIT.[MediaInfoTime],
			A.[DurationLinguisticTime] = PIT.[DurationLinguisticTime],
			A.[IsDiariced] = PIT.[IsDiariced],
			A.[ChannelsChanged] = PIT.[ChannelsChanged],
			A.[ValidChar] = ISNULL(PIT.[ValidChar], A.[ValidChar]),
			A.[ValidWords] = ISNULL(PIT.[ValidWords], A.[ValidWords]),
			A.[TotalPhrases] = PIT.[TotalPhrases],
			A.[CharsPerPhrase] = PIT.[CharsPerPhrase],
			A.[IsTranscribed] = PIT.[IsTranscribed],
			A.[IsCancel] = PIT.[IsCancel],
			A.[FileName] = PIT.[FileName],
			A.[ErrorMessage] = PIT.[ErrorMessage],
			A.[LastModifiedDate] = GETUTCDATE(),
			A.[SilenceInTime] = PIT.[SilenceInTime],
			A.[SilenceOutTime] = PIT.[SilenceOutTime],
			A.[SilenceTime] = PIT.[SilenceTime]
		FROM [dbo].[Audio] A
		INNER JOIN [dbo].[#ProcessInteractionTemp] PIT
			ON PIT.[VCC] = PIT.[VCC]
				AND A.[ID] = PIT.[ID]
				AND A.[Section] = PIT.[Section]
				AND A.[Part] = PIT.[Part]
		WHERE PIT.[Channel] = 'CALL'

	-- ACTUALIZAMOS LOS TEXT CON EL RESULTADO DE LA TABLA
	UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[ValidChar] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidChar], [dbo].[AsyncInteraction].[ValidChar]),
			[dbo].[AsyncInteraction].[ValidWords] = ISNULL([dbo].[#ProcessInteractionTemp].[ValidWords], [dbo].[AsyncInteraction].[ValidWords]),
			[dbo].[AsyncInteraction].[TotalPhrases] = [dbo].[#ProcessInteractionTemp].[TotalPhrases],
			[dbo].[AsyncInteraction].[CharsPerPhrase] = [dbo].[#ProcessInteractionTemp].[CharsPerPhrase],
			[dbo].[AsyncInteraction].[IsTranscribed] = [dbo].[#ProcessInteractionTemp].[IsTranscribed],
			[dbo].[AsyncInteraction].[IsCancel] = [dbo].[#ProcessInteractionTemp].[IsCancel],
			[dbo].[AsyncInteraction].[FileName] = [dbo].[#ProcessInteractionTemp].[FileName],
			[dbo].[AsyncInteraction].[ViewFileName] = [dbo].[#ProcessInteractionTemp].[ViewFileName],
			[dbo].[AsyncInteraction].[ErrorMessage] = [dbo].[#ProcessInteractionTemp].[ErrorMessage],
			[dbo].[AsyncInteraction].[LastModifiedDate] = GETUTCDATE()
	FROM [dbo].[#ProcessInteractionTemp]
	WHERE [dbo].[AsyncInteraction].[VCC] = [dbo].[#ProcessInteractionTemp].[VCC]
		AND [dbo].[AsyncInteraction].[Campaign] = [dbo].[#ProcessInteractionTemp].[Campaign]
		AND [dbo].[AsyncInteraction].[Channel] = [dbo].[#ProcessInteractionTemp].[Channel]
		AND [dbo].[AsyncInteraction].[ID] = [dbo].[#ProcessInteractionTemp].[ID]
		AND [dbo].[AsyncInteraction].[Folder] = [dbo].[#ProcessInteractionTemp].[Folder]

	DROP TABLE [dbo].[#ProcessInteractionTemp]
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
